[Bf-blender-cvs] [67650fb999e] temp-viewport-compositor-merge: Realtime Compositor: Rename processor operation

Omar Emara noreply at git.blender.org
Tue May 31 17:27:57 CEST 2022


Commit: 67650fb999e0dff16281775866aa08235c441048
Author: Omar Emara
Date:   Tue May 31 17:26:19 2022 +0200
Branches: temp-viewport-compositor-merge
https://developer.blender.org/rB67650fb999e0dff16281775866aa08235c441048

Realtime Compositor: Rename processor operation

===================================================================

M	source/blender/compositor/realtime_compositor/CMakeLists.txt
R061	source/blender/compositor/realtime_compositor/COM_conversion_processor_operation.hh	source/blender/compositor/realtime_compositor/COM_conversion_operation.hh
M	source/blender/compositor/realtime_compositor/COM_input_descriptor.hh
M	source/blender/compositor/realtime_compositor/COM_operation.hh
A	source/blender/compositor/realtime_compositor/COM_realize_on_domain_operation.hh
D	source/blender/compositor/realtime_compositor/COM_realize_on_domain_processor_operation.hh
R058	source/blender/compositor/realtime_compositor/COM_reduce_to_single_value_processor_operation.hh	source/blender/compositor/realtime_compositor/COM_reduce_to_single_value_operation.hh
R060	source/blender/compositor/realtime_compositor/COM_processor_operation.hh	source/blender/compositor/realtime_compositor/COM_simple_operation.hh
R060	source/blender/compositor/realtime_compositor/intern/conversion_processor_operation.cc	source/blender/compositor/realtime_compositor/intern/conversion_operation.cc
M	source/blender/compositor/realtime_compositor/intern/operation.cc
D	source/blender/compositor/realtime_compositor/intern/processor_operation.cc
R081	source/blender/compositor/realtime_compositor/intern/realize_on_domain_processor_operation.cc	source/blender/compositor/realtime_compositor/intern/realize_on_domain_operation.cc
R072	source/blender/compositor/realtime_compositor/intern/reduce_to_single_value_processor_operation.cc	source/blender/compositor/realtime_compositor/intern/reduce_to_single_value_operation.cc
A	source/blender/compositor/realtime_compositor/intern/simple_operation.cc

===================================================================

diff --git a/source/blender/compositor/realtime_compositor/CMakeLists.txt b/source/blender/compositor/realtime_compositor/CMakeLists.txt
index 589fab6c099..7867da9951e 100644
--- a/source/blender/compositor/realtime_compositor/CMakeLists.txt
+++ b/source/blender/compositor/realtime_compositor/CMakeLists.txt
@@ -17,41 +17,41 @@ set(INC
 set(SRC
   intern/compile_state.cc
   intern/context.cc
-  intern/conversion_processor_operation.cc
+  intern/conversion_operation.cc
   intern/domain.cc
   intern/evaluator.cc
   intern/input_single_value_operation.cc
   intern/node_operation.cc
   intern/operation.cc
-  intern/processor_operation.cc
-  intern/realize_on_domain_processor_operation.cc
-  intern/reduce_to_single_value_processor_operation.cc
+  intern/realize_on_domain_operation.cc
+  intern/reduce_to_single_value_operation.cc
   intern/result.cc
   intern/scheduler.cc
   intern/shader_node.cc
   intern/shader_operation.cc
   intern/shader_pool.cc
+  intern/simple_operation.cc
   intern/texture_pool.cc
   intern/unsupported_node_operation.cc
   intern/utilities.cc
 
   COM_compile_state.hh
   COM_context.hh
-  COM_conversion_processor_operation.hh
+  COM_conversion_operation.hh
   COM_domain.hh
   COM_evaluator.hh
   COM_input_descriptor.hh
   COM_input_single_value_operation.hh
   COM_node_operation.hh
   COM_operation.hh
-  COM_processor_operation.hh
-  COM_realize_on_domain_processor_operation.hh
-  COM_reduce_to_single_value_processor_operation.hh
+  COM_realize_on_domain_operation.hh
+  COM_reduce_to_single_value_operation.hh
   COM_result.hh
   COM_scheduler.hh
   COM_shader_node.hh
   COM_shader_operation.hh
   COM_shader_pool.hh
+  COM_simple_operation.hh
   COM_texture_pool.hh
   COM_unsupported_node_operation.hh
   COM_utilities.hh
diff --git a/source/blender/compositor/realtime_compositor/COM_input_descriptor.hh b/source/blender/compositor/realtime_compositor/COM_input_descriptor.hh
index c0e4f17db08..542d31ec76b 100644
--- a/source/blender/compositor/realtime_compositor/COM_input_descriptor.hh
+++ b/source/blender/compositor/realtime_compositor/COM_input_descriptor.hh
@@ -13,8 +13,8 @@ namespace blender::realtime_compositor {
 class InputDescriptor {
  public:
   /* The type of input. This may be different that the type of result that the operation will
-   * receive for the input, in which case, an implicit conversion input processor operation will
-   * be added to convert it to the required type. */
+   * receive for the input, in which case, an implicit conversion operation will be added as an
+   * input processor to convert it to the required type. */
   ResultType type;
   /* If true, then the input does not need to be realized on the domain of the operation before its
    * execution. See the discussion in COM_domain.hh for more information. */
dif

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/compositor/realtime_compositor/COM_conversion_processor_operation.hh b/source/blender/compositor/realtime_compositor/COM_conversion_operation.hh
similarity index 61%
rename from source/blender/compositor/realtime_compositor/COM_conversion_processor_operation.hh
rename to source/blender/compositor/realtime_compositor/COM_conversion_operation.hh
index 8e7d54e7a48..15e1d0722ea 100644
--- a/source/blender/compositor/realtime_compositor/COM_conversion_processor_operation.hh
+++ b/source/blender/compositor/realtime_compositor/COM_conversion_operation.hh
@@ -6,30 +6,30 @@
 
 #include "COM_context.hh"
 #include "COM_input_descriptor.hh"
-#include "COM_processor_operation.hh"
 #include "COM_result.hh"
+#include "COM_simple_operation.hh"
 
 namespace blender::realtime_compositor {
 
 /* -------------------------------------------------------------------------------------------------
- * Conversion Processor Operation
+ * Conversion Operation
  *
- * A processor that converts a result from a certain type to another. See the derived classes for
- * more details. */
-class ConversionProcessorOperation : public ProcessorOperation {
+ * A simple operation that converts a result from a certain type to another. See the derived
+ * classes for more details. */
+class ConversionOperation : public SimpleOperation {
  public:
-  using ProcessorOperation::ProcessorOperation;
+  using SimpleOperation::SimpleOperation;
 
   /* If the input result is a single value, execute_single is called. Otherwise, the shader
    * provided by get_conversion_shader is dispatched. */
   void execute() override;
 
-  /* Determine if a conversion processor operation is needed for the input with the given result
-   * and descriptor. If it is not needed, return a null pointer. If it is needed, return an
-   * instance of the appropriate conversion processor. */
-  static ProcessorOperation *construct_if_needed(Context &context,
-                                                 const Result &input_result,
-                                                 const InputDescriptor &input_descriptor);
+  /* Determine if a conversion operation is needed for the input with the given result and
+   * descriptor. If it is not needed, return a null pointer. If it is needed, return an instance of
+   * the appropriate conversion operation. */
+  static SimpleOperation *construct_if_needed(Context &context,
+                                              const Result &input_result,
+                                              const InputDescriptor &input_descriptor);
 
  protected:
   /* Convert the input single value result to the output single value result. */
@@ -40,13 +40,13 @@ class ConversionProcessorOperation : public ProcessorOperation {
 };
 
 /* -------------------------------------------------------------------------------------------------
- * Convert Float To Vector Processor Operation
+ * Convert Float To Vector Operation
  *
  * Takes a float result and outputs a vector result. All three components of the output are filled
  * with the input float. */
-class ConvertFloatToVectorProcessorOperation : public ConversionProcessorOperation {
+class ConvertFloatToVectorOperation : public ConversionOperation {
  public:
-  ConvertFloatToVectorProcessorOperation(Context &context);
+  ConvertFloatToVectorOperation(Context &context);
 
   void execute_single(const Result &input, Result &output) override;
 
@@ -54,13 +54,13 @@ class ConvertFloatToVectorProcessorOperation : public ConversionProcessorOperati
 };
 
 /* -------------------------------------------------------------------------------------------------
- * Convert Float To Color Processor Operation
+ * Convert Float To Color Operation
  *
  * Takes a float result and outputs a color result. All three color channels of the output are
  * filled with the input float and the alpha channel is set to 1. */
-class ConvertFloatToColorProcessorOperation : public ConversionProcessorOperation {
+class ConvertFloatToColorOperation : public ConversionOperation {
  public:
-  ConvertFloatToColorProcessorOperation(Context &context);
+  ConvertFloatToColorOperation(Context &context);
 
   void execute_single(const Result &input, Result &output) override;
 
@@ -68,13 +68,13 @@ class ConvertFloatToColorProcessorOperation : public ConversionProcessorOperatio
 };
 
 /* -------------------------------------------------------------------------------------------------
- * Convert Color To Float Processor Operation
+ * Convert Color To Float Operation
  *
  * Takes a color result and outputs a float result. The output is the average of the three color
  * channels, the alpha channel is ignored. */
-class ConvertColorToFloatProcessorOperation : public ConversionProcessorOperation {
+class ConvertColorToFloatOperation : public ConversionOperation {
  public:
-  ConvertColorToFloatProcessorOperation(Context &context);
+  ConvertColorToFloatOperation(Context &context);
 
   void execute_single(const Result &input, Result &output) override;
 
@@ -82,13 +82,13 @@ class ConvertColorToFloatProcessorOperation : public ConversionProcessorOperatio
 };
 
 /* -------------------------------------------------------------------------------------------------
- * Convert Color To Vector Processor Operation
+ * Convert Color To Vector Operation
  *
  * Takes a color result and outputs a vector result. The output is a copy of the three color
  * channels to the three vector components. */
-class ConvertColorToVectorProcessorOperation : public ConversionProcessorOperation {
+class ConvertColorToVectorOperation : public ConversionOperation {
  public:
-  ConvertColorToVectorProcessorOperation(Context &context);
+  ConvertColorToVectorOperation(Context &context);
 
   void execute_single(const Result &input, Result &output) override;
 
@@ -96,13 +96,13 @@ class ConvertColorToVectorProcessorOperation : public ConversionProcessorOperati
 };
 
 /* -------------------------------------------------------------------------------------------------
- * Convert Vector To Float Processor Operation
+ * Convert Vector To Float Operation
  *
  * Takes a vector result and outputs a float result. The output is the average of the three
  * components. */
-class ConvertVectorToFloatProcessorOperation : public ConversionProcessorOperation {
+class ConvertVectorToFloatOperation : public ConversionOperation {
  public:
-  ConvertVectorToFloatProcessorOperation(Context &context);
+  ConvertVectorToFloatOperation(Context &context);
 
   void execute_single(const Result &input, Result &output) override;
 
@@ -110,13 +110,13 @@ class ConvertVectorToFloatProcessorOperation : public ConversionProcessorOperati
 };
 
 /* -------------------------------------------------------------------------------------------------
- * Convert Vector To Color Processor Operation
+ * Convert Vector To Color Operation
  *
  * Takes a vector result and outputs a color result. The output is a copy of the three vector
  * components to the three color channels with the alpha channel set to 1. */
-class ConvertVectorToColorProcessorOperation : public ConversionProcessorOperation {
+class ConvertVectorToColorOperation : public ConversionOperation {
  public:
-  ConvertVectorToColorProcessorOperation(Context &context);
+  ConvertVectorToColorOperation(Context &context);
 
   void execute_single(const Result &input, Result &output) override;
 